<?php
/**
 * store-wp functions and definitions
 *
 * @package Onepage
 */

/**
 * Set the content width based on the theme's design and stylesheet.
 */
if ( ! isset( $content_width ) ) {
    $content_width = 770; /* pixels */
}

if ( ! function_exists( 'onepage_setup' ) ) :
/**
 * Sets up theme defaults and registers support for various WordPress features.
 *
 * Note that this function is hooked into the after_setup_theme hook, which
 * runs before the init hook. The init hook is too late for some features, such
 * as indicating support for post thumbnails.
 */
function onepage_setup() {

    /*
     * Make theme available for translation.
     * Translations can be filed in the /languages/ directory.
     */
    load_theme_textdomain( 'onepage', get_template_directory() . '/languages' );

    // Add default posts and comments RSS feed links to head.
    add_theme_support( 'automatic-feed-links' );

    //Let WordPress manage the document title.
    add_theme_support( 'title-tag' );

    //Enable support for Post Thumbnails on posts and pages.
    add_theme_support( 'post-thumbnails' );

    //This theme uses wp_nav_menu() in one location.
    register_nav_menus( array(
        'homepage-menu' => __( 'Home Page Menu', 'onepage' ),
        'primary-menu' => __( 'Primary Menu', 'onepage' ),
    ) );

    //Switch default core markup for search form, comment form, and comments to output valid HTML5.
    add_theme_support( 'html5', array(
        'search-form', 'comment-form', 'comment-list', 'gallery', 'caption',
    ) );

    //Enable support for Post Formats.
    add_theme_support( 'post-formats', array(
        'aside', 'image', 'video', 'quote', 'link',
    ) );

    // Set up the WordPress core custom background feature.
    add_theme_support( 'custom-background', apply_filters( 'onepage_custom_background_args', array(
        'default-color' => '#fff',
        'default-image' => '',
    ) ) );

    // post slider image.
    add_image_size( 'post-slider', 394, 300, true ); // (cropped)

    // add editor style
    add_editor_style( '/core-framework/css/editor-style.css' );
}
endif; // onepage_setup
add_action( 'after_setup_theme', 'onepage_setup' );

//Implement the Custom Header feature.
require get_template_directory() . '/core-framework/custom-header.php';

//Custom template tags for this theme.
require get_template_directory() . '/core-framework/template-tags.php';

//Custom functions that act independently of the theme templates.
require get_template_directory() . '/core-framework/extras.php';

//Load Jetpack compatibility file.
require get_template_directory() . '/core-framework/jetpack.php';

//Core Framework.
require get_template_directory() . '/core-framework/func/function-action.php';
require get_template_directory() . '/core-framework/func/function-widget.php';
require get_template_directory() . '/core-framework/func/function-script.php';
require get_template_directory() . '/core-framework/partials/page-metabox.php';
if ( is_admin() ) {
    require get_template_directory() . '/core-framework/welcome/welcome-screen.php';
}
//Loads the Options Panel
require get_template_directory() . '/core-framework/options/options-framework.php';
// Loads options.php from child or parent theme
require get_template_directory() . '/options.php';

/*-----------------------------------------------
 * Add favicon.
 -----------------------------------------------*/
function onepage_favicon() { ?>
<?php if ( igthemes_option('favicon')) { ?>
    <link rel="shortcut icon" href="<?php echo esc_url(get_option( 'onepage_favicon', '' )); ?>">
<?php } ?>
<?php if ( igthemes_option('icon_iphone')) { ?>
    <link rel="apple-touch-icon" sizes="57x57" href="<?php echo esc_url(get_option( 'onepage_icon_iphone', '' )); ?>">
<?php } ;?>
<?php if ( igthemes_option('icon_ipad')) { ?>
    <link rel="apple-touch-icon" sizes="76x76" href="<?php echo esc_url(get_option( 'onepage_icon_ipad', '' )); ?>">
<?php } ?>
<?php if ( igthemes_option('icon_iphone_retina')) { ?>
    <link rel="apple-touch-icon" sizes="120x120" href="<?php echo esc_url(get_option( 'onepage_icon_iphone_retina', '' )); ?>">
<?php } ?>
<?php if ( igthemes_option('icon_ipad_retina')) { ?>
    <link rel="apple-touch-icon" sizes="152x152" href="<?php echo esc_url(get_option( 'onepage_icon_ipad_retina', '' )); ?>">
<?php } ?>
<?php if ( igthemes_option('win_tile_image')) { ?>
    <meta name="msapplication-TileImage" content="<?php echo esc_url(get_option( 'onepage_win_tile_image', '' )); ?>"/>
<?php } ?>
<?php if ( igthemes_option('win_tile_color')) { ?>
    <meta name="msapplication-TileColor" content="<?php echo esc_attr(get_option( 'onepage_win_tile_color', '' )); ?>"/>
<?php } ?>
<?php }
add_action('wp_head', 'onepage_favicon');

/*-----------------------------------------------
 * Woocommerce support.
 -----------------------------------------------*/
add_theme_support( 'woocommerce' );

